define(
//begin v1.x content
{
	"dayPeriods-standAlone-abbr-noon": "podne",
	"field-tue-relative+-1": "prošli utorak",
	"field-year": "godina",
	"dateFormatItem-yw": "w. 'sedmica' 'u' Y.",
	"dayPeriods-format-abbr-afternoon1": "poslijepodne",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"dateFormatItem-ms": "mm:ss",
	"timeFormat-short": "HH:mm",
	"field-minute": "minuta",
	"field-tue-narrow-relative+0": "ovaj uto.",
	"field-tue-narrow-relative+1": "sljedeći uto.",
	"field-thu-short-relative+0": "ovaj čet.",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "danas",
	"field-thu-short-relative+1": "sljedeći čet.",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "prošla sri.",
	"field-year-narrow": "g.",
	"field-era-short": "era",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"dayPeriods-format-narrow-am": "prijepodne",
	"field-weekdayOfMonth": "dan u mjesecu",
	"field-second-short": "sek.",
	"dayPeriods-standAlone-abbr-morning1": "ujutro",
	"dateFormatItem-MMMd": "d. MMM",
	"dayPeriods-format-narrow-morning1": "ujutro",
	"field-weekdayOfMonth-narrow": "d. u mj.",
	"dayPeriods-format-abbr-am": "AM",
	"field-month-relative+0": "ovaj mjesec",
	"field-week-relative+0": "ove sedmice",
	"timeFormat-medium": "HH:mm:ss",
	"field-month-relative+1": "sljedeći mjesec",
	"field-week-relative+1": "sljedeće sedmice",
	"field-sun-narrow-relative+0": "ova ned.",
	"field-mon-short-relative+0": "ovaj pon.",
	"field-sun-narrow-relative+1": "sljedeća ned.",
	"field-mon-short-relative+1": "sljedeći pon",
	"field-second-relative+0": "sada",
	"months-standAlone-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"dayPeriods-standAlone-wide-noon": "podne",
	"eraNames": [
		"prije nove ere",
		"nove ere"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"field-weekOfMonth": "sedmica u mjesecu",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"field-month-short": "mj.",
	"field-day": "dan",
	"dayPeriods-standAlone-wide-night1": "po noći",
	"field-year-relative+-1": "prošle godine",
	"field-dayOfYear-short": "dan u god.",
	"dayPeriods-format-wide-am": "prijepodne",
	"field-sat-short-relative+-1": "prošla sub.",
	"dayPeriods-format-narrow-afternoon1": "poslijepodne",
	"dayPeriods-format-wide-afternoon1": "poslijepodne",
	"field-hour-relative+0": "ovaj sat",
	"field-wed-relative+-1": "prošla srijeda",
	"dateTimeFormat-medium": "{1} {0}",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"dayPeriods-standAlone-narrow-noon": "podne",
	"field-sat-narrow-relative+-1": "prošla sub.",
	"field-second": "sekunda",
	"dayPeriods-standAlone-wide-pm": "popodne",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d. MMMM y.",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"dayPeriods-standAlone-abbr-midnight": "ponoć",
	"field-quarter": "kvartal",
	"field-week-short": "sed.",
	"dayPeriods-format-narrow-midnight": "ponoć",
	"dateFormatItem-yMMMEd": "E, d. MMM y.",
	"quarters-standAlone-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"dayPeriods-format-wide-evening1": "navečer",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "ovaj uto.",
	"field-tue-short-relative+1": "sljedeći uto.",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "mjesec",
	"dayPeriods-standAlone-abbr-night1": "po noći",
	"field-day-narrow": "dan",
	"dayPeriods-standAlone-narrow-afternoon1": "poslijepodne",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "prijepodne/poslijepodne",
	"field-sat-short-relative+0": "ova sub.",
	"field-sat-short-relative+1": "sljedeća sub.",
	"dayPeriods-format-narrow-pm": "popodne",
	"dateFormat-medium": "d. MMM y.",
	"eraAbbr": [
		"p. n. e.",
		"n. e."
	],
	"quarters-standAlone-abbr": [
		"KV1",
		"KV2",
		"KV3",
		"KV4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"field-second-narrow": "s",
	"dayPeriods-standAlone-narrow-night1": "po noći",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-year-short": "god.",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"months-format-narrow": [
		"j",
		"f",
		"m",
		"a",
		"m",
		"j",
		"j",
		"a",
		"s",
		"o",
		"n",
		"d"
	],
	"dayPeriods-format-wide-morning1": "ujutro",
	"field-quarter-relative+-1": "posljednji kvartal",
	"dayPeriods-standAlone-narrow-am": "prijepodne",
	"field-dayperiod-narrow": "prijepodne/poslijepodne",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "popodne",
	"field-dayOfYear": "dan u godini",
	"field-sat-relative+-1": "prošla subota",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "sat",
	"dateFormatItem-yQQQQ": "QQQQ y.",
	"months-format-wide": [
		"januar",
		"februar",
		"mart",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"septembar",
		"oktobar",
		"novembar",
		"decembar"
	],
	"dayPeriods-format-wide-night1": "po noći",
	"dateFormat-full": "EEEE, d. MMMM y.",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "kv.",
	"field-sat-narrow-relative+0": "ova sub.",
	"dateFormatItem-Hmv": "HH:mm (v)",
	"field-fri-relative+0": "ovaj petak",
	"field-sat-narrow-relative+1": "sljedeća sub.",
	"field-fri-relative+1": "sljedeći petak",
	"dateFormatItem-EBhm": "E h:mm B",
	"dayPeriods-format-narrow-noon": "podne",
	"field-sun-short-relative+0": "ova ned.",
	"field-sun-short-relative+1": "sljedeća ned.",
	"field-week-relative+-1": "prošle sedmice",
	"dateFormatItem-Ehm": "E h:mm a",
	"months-format-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dayPeriods-format-wide-midnight": "ponoć",
	"timeFormat-long": "HH:mm:ss z",
	"field-quarter-relative+0": "ovaj kvartal",
	"field-minute-relative+0": "ova minuta",
	"field-quarter-relative+1": "sljedeći kvartal",
	"field-wed-short-relative+-1": "prošla sri.",
	"dateFormatItem-yMMM": "MMM y.",
	"dateFormat-short": "d. M. y.",
	"dateFormatItem-Bh": "h B",
	"dayPeriods-format-abbr-night1": "po noći",
	"dateFormatItem-MMMMW": "W. 'sedmica' 'mjesec' MMMM",
	"field-thu-short-relative+-1": "prošli čet.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-mon-narrow-relative+-1": "prošli pon.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "prošli čet.",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "sed. u mj.",
	"field-tue-narrow-relative+-1": "prošli uto.",
	"dayPeriods-format-abbr-evening1": "navečer",
	"dayPeriods-standAlone-narrow-pm": "popodne",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"januar",
		"februar",
		"mart",
		"april",
		"maj",
		"juni",
		"juli",
		"august",
		"septembar",
		"oktobar",
		"novembar",
		"decembar"
	],
	"field-wed-short-relative+0": "ova sri.",
	"field-wed-short-relative+1": "sljedeća sri.",
	"dateFormatItem-Hmsv": "HH:mm:ss (v)",
	"field-sun-relative+-1": "prošla nedjelja",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateTimeFormat-full": "{1} 'u' {0}",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-d": "d.",
	"field-weekday": "dan u sedmici",
	"dayPeriods-standAlone-wide-evening1": "navečer",
	"field-sat-relative+0": "ova subota",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "sljedeća subota",
	"months-standAlone-abbr": [
		"jan",
		"feb",
		"mar",
		"apr",
		"maj",
		"jun",
		"jul",
		"aug",
		"sep",
		"okt",
		"nov",
		"dec"
	],
	"dateFormatItem-hmsv": "h:mm:ss a (v)",
	"dayPeriods-format-abbr-morning1": "ujutro",
	"dayPeriods-standAlone-narrow-evening1": "navečer",
	"dateFormatItem-yMM": "M/y",
	"field-dayOfYear-narrow": "dan u g.",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-weekdayOfMonth-short": "dan u mj.",
	"dateFormatItem-MEd": "E, d.M.",
	"field-zone-narrow": "zona",
	"dateFormatItem-y": "y.",
	"field-thu-narrow-relative+0": "ovaj čet.",
	"field-sun-narrow-relative+-1": "prošla ned.",
	"field-mon-short-relative+-1": "prošli pon.",
	"field-thu-narrow-relative+1": "sljedeći čet.",
	"field-thu-relative+0": "ovaj četvrtak",
	"dayPeriods-standAlone-abbr-afternoon1": "poslijepodne",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "prošli pet.",
	"dateFormatItem-hmv": "h:mm a (v)",
	"dayPeriods-format-abbr-noon": "podne",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-yMd": "d.M.y.",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-week": "sedmica",
	"quarters-format-wide": [
		"Prvi kvartal",
		"Drugi kvartal",
		"Treći kvartal",
		"Četvrti kvartal"
	],
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "ova sri.",
	"field-wed-narrow-relative+1": "sljedeća sri.",
	"dayPeriods-standAlone-wide-morning1": "ujutro",
	"field-dayperiod-short": "prijepodne/poslijepodne",
	"field-fri-short-relative+0": "ovaj pet.",
	"field-fri-short-relative+1": "sljedeći pet.",
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dayPeriods-standAlone-narrow-morning1": "ujutro",
	"dayPeriods-format-abbr-midnight": "ponoć",
	"field-hour-short": "h",
	"field-zone-short": "zona",
	"quarters-format-abbr": [
		"KV1",
		"KV2",
		"KV3",
		"KV4"
	],
	"field-month-narrow": "mj.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "prošli pet.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "prošli petak",
	"eraNarrow": [
		"p.n.e.",
		"n.e."
	],
	"dateFormatItem-Bhms": "h:mm:ss B",
	"dayPeriods-format-wide-noon": "podne",
	"field-tue-short-relative+-1": "prošli uto.",
	"field-minute-narrow": "min.",
	"dayPeriods-standAlone-wide-afternoon1": "poslijepodne",
	"dateFormatItem-yQQQ": "QQQ y.",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-mon-narrow-relative+0": "ovaj pon.",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "sljedeći pon.",
	"dayPeriods-standAlone-wide-midnight": "ponoć",
	"dateFormatItem-yM": "MM/y",
	"field-zone": "vremenska zona",
	"dateFormatItem-yMMMM": "LLLL y.",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "s. u mj.",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-yMEd": "E, d.M.y.",
	"field-weekday-narrow": "dan u sed.",
	"dayPeriods-standAlone-narrow-midnight": "ponoć",
	"field-quarter-narrow": "kv.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-day-relative+-1": "jučer",
	"field-sun-short-relative+-1": "prošla ned.",
	"field-day-relative+-2": "prekjučer",
	"dayPeriods-format-narrow-night1": "po noći",
	"field-weekday-short": "dan u sed.",
	"dateFormatItem-Bhm": "h:mm B",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-MMdd": "d. M.",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"dateFormatItem-yMMMd": "d. MMM y.",
	"dateFormatItem-Gy": "y. G",
	"field-era": "era",
	"field-week-narrow": "sed.",
	"field-day-short": "dan",
	"dayPeriods-standAlone-abbr-evening1": "navečer",
	"field-fri-narrow-relative+0": "ovaj pet.",
	"dayPeriods-format-narrow-evening1": "navečer",
	"field-fri-narrow-relative+1": "sljedeći pet.",
	"dayPeriods-standAlone-wide-am": "prijepodne"
}
//end v1.x content
);